==> bcc-core-api-node-sdk-1.12.0.tgz: package/lib/esm/api/groupsClient.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { GenericClient } from "./genericClient.js";
import { GroupMembersClient } from "./groupMembersClient.js";
export class GroupsClient {
    constructor(basePath, auth, queryOptions) {
        this.auth = auth;
        this.basePath = basePath;
        this.queryOptions = queryOptions;
        this.client = new GenericClient({
            basePath: basePath,
            endpointPath: "/groups",
            auth: auth,
            writeTypeName: "GroupWrite",
            singleResponseTypeName: "WrappedGroup",
            multipleResponseTypeName: "WrappedWithMetaArrayGroup",
            patchTypeName: "GroupWritePatch",
            queryOptions: queryOptions,
        });
    }
    create(group) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.create(group);
        });
    }
    remove(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.remove(id);
        });
    }
    get(id, query = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.get(id, query);
        });
    }
    find(findParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.find(findParams);
        });
    }
    patch(id, group) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.patch(id, group);
        });
    }
    getGroupMembersClient(groupUid) {
        return new GroupMembersClient(this.basePath, groupUid, this.auth, this.queryOptions);
    }
    getMember(groupUid, memberUid, query = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const membersClient = this.getGroupMembersClient(groupUid);
            return membersClient.get(memberUid, query);
        });
    }
    findMembers(groupUid, findParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const membersClient = this.getGroupMembersClient(groupUid);
            return membersClient.find(findParams);
        });
    }
    addMember(groupUid, member) {
        return __awaiter(this, void 0, void 0, function* () {
            const membersClient = this.getGroupMembersClient(groupUid);
            return membersClient.create(member);
        });
    }
    removeMember(groupUid, memberUid) {
        return __awaiter(this, void 0, void 0, function* () {
            const membersClient = this.getGroupMembersClient(groupUid);
            return membersClient.remove(memberUid);
        });
    }
}

==> bcc-core-api-node-sdk-1.14.1.tgz: package/lib/esm/api/groupsClient.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { GenericClient } from "./genericClient.js";
import { GroupMembersClient } from "./groupMembersClient.js";
export class GroupsClient {
    constructor(basePath, auth, queryOptions) {
        this.auth = auth;
        this.basePath = basePath;
        this.queryOptions = queryOptions;
        this.client = new GenericClient({
            basePath: basePath,
            endpointPath: "/groups",
            auth: auth,
            writeTypeName: "GroupWrite",
            singleResponseTypeName: "WrappedGroup",
            multipleResponseTypeName: "WrappedWithMetaArrayGroup",
            queryOptions: queryOptions,
        });
    }
    create(group) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.create(group);
        });
    }
    remove(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.remove(id);
        });
    }
    get(id, query = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.get(id, query);
        });
    }
    find(findParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.find(findParams);
        });
    }
    update(id, group) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.update(id, group);
        });
    }
    getGroupMembersClient(groupUid) {
        return new GroupMembersClient(this.basePath, groupUid, this.auth, this.queryOptions);
    }
    getMember(groupUid, memberUid, query = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const membersClient = this.getGroupMembersClient(groupUid);
            return membersClient.get(memberUid, query);
        });
    }
    findMembers(groupUid, findParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const membersClient = this.getGroupMembersClient(groupUid);
            return membersClient.find(findParams);
        });
    }
    addMember(groupUid, member) {
        return __awaiter(this, void 0, void 0, function* () {
            const membersClient = this.getGroupMembersClient(groupUid);
            return membersClient.create(member);
        });
    }
    removeMember(groupUid, memberUid) {
        return __awaiter(this, void 0, void 0, function* () {
            const membersClient = this.getGroupMembersClient(groupUid);
            return membersClient.remove(memberUid);
        });
    }
}
